Struct micro_ldtk::ldtk::LayerInstance
source · pub struct LayerInstance {Show 24 fields
pub c_hei: i64,
pub c_wid: i64,
pub grid_size: i64,
pub identifier: String,
pub opacity: f64,
pub px_total_offset_x: i64,
pub px_total_offset_y: i64,
pub tileset_def_uid: Option<i64>,
pub tileset_rel_path: Option<String>,
pub layer_instance_type: String,
pub auto_layer_tiles: Vec<TileInstance>,
pub entity_instances: Vec<EntityInstance>,
pub grid_tiles: Vec<TileInstance>,
pub iid: String,
pub int_grid: Option<Vec<IntGridValueInstance>>,
pub int_grid_csv: Vec<i64>,
pub layer_def_uid: i64,
pub level_id: i64,
pub optional_rules: Vec<i64>,
pub override_tileset_uid: Option<i64>,
pub px_offset_x: i64,
pub px_offset_y: i64,
pub seed: i64,
pub visible: bool,
}Fields
c_hei: i64Grid-based height
c_wid: i64Grid-based width
grid_size: i64Grid size
identifier: StringLayer definition identifier
opacity: f64Layer opacity as Float [0-1]
px_total_offset_x: i64Total layer X pixel offset, including both instance and definition offsets.
px_total_offset_y: i64Total layer Y pixel offset, including both instance and definition offsets.
tileset_def_uid: Option<i64>The definition UID of corresponding Tileset, if any.
tileset_rel_path: Option<String>The relative path to corresponding Tileset, if any.
layer_instance_type: StringLayer type (possible values: IntGrid, Entities, Tiles or AutoLayer)
auto_layer_tiles: Vec<TileInstance>An array containing all tiles generated by Auto-layer rules. The array is already sorted
in display order (ie. 1st tile is beneath 2nd, which is beneath 3rd etc.).
Note: if multiple tiles are stacked in the same cell as the result of different rules,
all tiles behind opaque ones will be discarded.
entity_instances: Vec<EntityInstance>grid_tiles: Vec<TileInstance>iid: StringUnique layer instance identifier
int_grid: Option<Vec<IntGridValueInstance>>WARNING: this deprecated value is no longer exported since version 1.0.0 Replaced
by: intGridCsv
int_grid_csv: Vec<i64>A list of all values in the IntGrid layer, stored in CSV format (Comma Separated
Values).
Order is from left to right, and top to bottom (ie. first row from left to
right, followed by second row, etc).
0 means “empty cell” and IntGrid values
start at 1.
The array size is __cWid x __cHei cells.
layer_def_uid: i64Reference the Layer definition UID
level_id: i64Reference to the UID of the level containing this layer instance
optional_rules: Vec<i64>An Array containing the UIDs of optional rules that were enabled in this specific layer instance.
override_tileset_uid: Option<i64>This layer can use another tileset by overriding the tileset UID here.
px_offset_x: i64X offset in pixels to render this layer, usually 0 (IMPORTANT: this should be added to
the LayerDef optional offset, so you should probably prefer using __pxTotalOffsetX
which contains the total offset value)
px_offset_y: i64Y offset in pixels to render this layer, usually 0 (IMPORTANT: this should be added to
the LayerDef optional offset, so you should probably prefer using __pxTotalOffsetX
which contains the total offset value)
seed: i64Random seed used for Auto-Layers rendering
visible: boolLayer instance visibility